RatingDTO class
A DTO for the rating model.
This class provides a common structure for all rating DTOs, including a rate, comment, isVerified, photos, product, user, and store. It also provides methods to convert the DTO to and from a JSON object.
Constructors
Properties
- comment ↔ String?
-
getter/setter pair
- createdAt ↔ String?
-
The time when the DTO was created.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the DTO.
getter/setter pairinherited
- isActive ↔ bool?
-
Whether the DTO is active.
getter/setter pairinherited
- isDeleted ↔ bool?
-
Whether the DTO has been deleted.
getter/setter pairinherited
- isVerified ↔ bool?
-
getter/setter pair
-
photos
↔ List<
PhotoDTO> ? -
getter/setter pair
- product ↔ ProductDTO?
-
getter/setter pair
- rate ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- store ↔ StoreDTO?
-
getter/setter pair
- updatedAt ↔ String?
-
The time when the DTO was last updated.
getter/setter pairinherited
- user ↔ ProfileDTO?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts the BaseDTO to a JSON object.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited