StoreInfoDTO class

A DTO for the store info model.

This class provides a common structure for all store info DTOs, including a name, official title, domain, slug, logo photo, banner photo, and address. It also provides methods to convert the DTO to and from a JSON object.

Inheritance

Constructors

StoreInfoDTO({String? id, String? createdAt, String? updatedAt, bool? isActive, bool? isDeleted, String? name, String? officialTitle, String? domain, String? slug, PhotoDTO? logoPhoto, PhotoDTO? bannerPhoto, AddressDTO? address})
StoreInfoDTO.fromJson(Map<String, dynamic> json)

Properties

address AddressDTO?
getter/setter pair
bannerPhoto PhotoDTO?
getter/setter pair
createdAt String?
The time when the DTO was created.
getter/setter pairinherited
domain String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of the DTO.
getter/setter pairinherited
isActive bool?
Whether the DTO is active.
getter/setter pairinherited
isDeleted bool?
Whether the DTO has been deleted.
getter/setter pairinherited
logoPhoto PhotoDTO?
getter/setter pair
name String?
getter/setter pair
officialTitle String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
getter/setter pair
updatedAt String?
The time when the DTO was last updated.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts the BaseDTO to a JSON object.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited